const Mesa = require('vendor/Mesa.js');

/**
 * A Mesa Script exports a class with a script() method.
 */
module.exports = new class {

  /**
   * Mesa Script
   *
   * @param {object} payload The payload data
   * @param {object} context Additional context about this task
   */
  script = (payload, context) => {
    const vars = context.steps;

    let numOrders = vars.loop.count;
    let totalSpent = vars.loop_1.sum;

    let tier = this.getTier(vars);

    let tags = [];
    if (numOrders > 2) {
      tags.push("Repeat Customer");
    }
    if (tier) {
      tags.push(tier);
    }

    Mesa.output.next({"tags": tags});
  }

  getTier = (vars) => {
    let tiers = vars.transform;

    let tiersArray = [];
    for (let spendMinimum in tiers) {
      tiersArray.push({
        "spend_minimum": spendMinimum,
        "tier": tiers[spendMinimum],
      });
    }
    tiersArray.reverse();
    Mesa.log.info("tiers array", tiersArray);

    for (let row of tiersArray) {
      Mesa.log.info("minimum", row.spend_minimum);
      if (vars.loop_1.sum >= row.spend_minimum) {
        return row.tier;
      }
    }

    return null;
  }
}
